@@ -243,8 +243,7 @@ class Converter:
         """Append a record to the converter."""
         self._check_record(record)
 
-        # TODO test this later
-        # self.records.append(record)
+        self.records.append(record)
         self.prefix_map[record.prefix] = record.uri_prefix
         for prefix_synonym in record.prefix_synonyms:
             self.prefix_map[prefix_synonym] = record.uri_prefix
@@ -659,13 +658,39 @@ class Converter:
         prefix, identifier = self.parse_curie(curie)
         return self.expand_pair(prefix, identifier)
 
+    def expand_all(self, curie: str) -> Optional[Collection[str]]:
+        """Expand a CURIE pair to all possible URIs.
+
+        :param curie:
+            A string representing a compact URI
+        :returns:
+            A list of URIs that this converter can create for the given CURIE. The
+            first entry is the "standard" URI then others are based on URI prefix
+            synonyms. If the prefix is not registered to this converter, none is
+            returned.
+
+        >>> priority_prefix_map = {
+        ...     "CHEBI": [
+        ...         "http://purl.obolibrary.org/obo/CHEBI_",
+        ...         "https://www.ebi.ac.uk/chebi/searchId.do?chebiId=CHEBI:",
+        ...     ],
+        ... }
+        >>> converter = Converter.from_priority_prefix_map(priority_prefix_map)
+        >>> converter.expand_all("CHEBI:138488")
+        ['http://purl.obolibrary.org/obo/CHEBI_138488', 'https://www.ebi.ac.uk/chebi/searchId.do?chebiId=CHEBI:138488']
+        >>> converter.expand_all("NOPE:NOPE") is None
+        True
+        """
+        prefix, identifier = self.parse_curie(curie)
+        return self.expand_pair_all(prefix, identifier)
+
     def parse_curie(self, curie: str) -> Tuple[str, str]:
         """Parse a CURIE."""
         prefix, identifier = curie.split(self.delimiter, 1)
         return prefix, identifier
 
     def expand_pair(self, prefix: str, identifier: str) -> Optional[str]:
-        """Expand a CURIE pair to a URI.
+        """Expand a CURIE pair to the standard URI.
 
         :param prefix:
             The prefix of the CURIE
@@ -689,6 +714,61 @@ class Converter:
             return None
         return uri_prefix + identifier
 
+    def expand_pair_all(self, prefix: str, identifier: str) -> Optional[Collection[str]]:
+        """Expand a CURIE pair to all possible URIs.
+
+        :param prefix:
+            The prefix of the CURIE
+        :param identifier:
+            The local unique identifier of the CURIE
+        :returns:
+            A list of URIs that this converter can create for the given CURIE. The
+            first entry is the "standard" URI then others are based on URI prefix
+            synonyms. If the prefix is not registered to this converter, none is
+            returned.
+
+        >>> priority_prefix_map = {
+        ...     "CHEBI": [
+        ...         "http://purl.obolibrary.org/obo/CHEBI_",
+        ...         "https://www.ebi.ac.uk/chebi/searchId.do?chebiId=CHEBI:",
+        ...     ],
+        ... }
+        >>> converter = Converter.from_priority_prefix_map(priority_prefix_map)
+        >>> converter.expand_pair_all("CHEBI", "138488")
+        ['http://purl.obolibrary.org/obo/CHEBI_138488', 'https://www.ebi.ac.uk/chebi/searchId.do?chebiId=CHEBI:138488']
+        >>> converter.expand_pair_all("NOPE", "NOPE") is None
+        True
+        """
+        record = self.get_record(prefix)
+        if record is None:
+            return None
+        rv = [record.uri_prefix + identifier]
+        for uri_prefix_synonyms in record.uri_prefix_synonyms:
+            rv.append(uri_prefix_synonyms + identifier)
+        return rv
+
+    def standardize_prefix(self, prefix: str) -> Optional[str]:
+        """Standardize a prefix.
+
+        :param prefix:
+            The prefix of the CURIE
+        :returns:
+            The standardized version of this prefix wrt this converter.
+            If the prefix is not registered in this converter, returns none.
+
+        >>> from curies import Converter, Record
+        >>> converter = Converter.from_extended_prefix_map([
+        ...     Record(prefix="CHEBI", prefix_synonyms=["chebi"], uri_prefix="..."),
+        ... ])
+        >>> converter.standardize_prefix("chebi")
+        'CHEBI'
+        >>> converter.standardize_prefix("CHEBI")
+        'CHEBI:138488'
+        >>> converter.standardize_prefix("NOPE") is None
+        True
+        """
+        return self.synonym_to_prefix.get(prefix)
+
     def standardize_curie(self, curie: str) -> Optional[str]:
         """Standardize a CURIE.
 
@@ -712,7 +792,7 @@ class Converter:
         True
         """
         prefix, identifier = self.parse_curie(curie)
-        norm_prefix = self.synonym_to_prefix.get(prefix)
+        norm_prefix = self.standardize_prefix(prefix)
         if norm_prefix is None:
             return None
         return self.format_curie(norm_prefix, identifier)
@@ -826,6 +906,14 @@ class Converter:
                 writer.writerow(_header)
             writer.writerows(rows)
 
+    def get_record(self, prefix: str) -> Optional[Record]:
+        """Get the record for the prefix."""
+        # TODO better data structure for this
+        for record in self.records:
+            if record.prefix == prefix:
+                return record
+        return None
+
 
 def _f(x: str) -> str:
     return x
